"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const anchor = __importStar(require("@project-serum/anchor"));
const web3_js_1 = require("@solana/web3.js");
const spl_token_bonding_1 = require("@strata-foundation/spl-token-bonding");
const spl_token_collective_1 = require("@strata-foundation/spl-token-collective");
const spl_utils_1 = require("@strata-foundation/spl-utils");
const fs_1 = __importDefault(require("fs"));
function timeIncrease(curve) {
    return curve
        // Causes a 9.09091% bump
        .addCurve(6 * 60 * 60, // 6 hours after launch
    new spl_token_bonding_1.ExponentialCurveConfig({
        c: 1,
        b: 0,
        pow: 1,
        frac: 10
    }), null, {
        percentage: (0, spl_utils_1.percent)(10),
        interval: 6 * 60 * 60, // 6 hours
    })
        // 7.57576% bump
        .addCurve(12 * 60 * 60, // 12 hours after launch
    new spl_token_bonding_1.ExponentialCurveConfig({
        c: 1,
        b: 0,
        pow: 1,
        frac: 5
    }), null, {
        percentage: (0, spl_utils_1.percent)(8),
        interval: 6 * 60 * 60, // 6 hours
    })
        // 8.33333% bump
        .addCurve(24 * 60 * 60, // 24 hours after launch
    new spl_token_bonding_1.ExponentialCurveConfig({
        c: 1,
        b: 0,
        pow: 1,
        frac: 3
    }), null, {
        percentage: (0, spl_utils_1.percent)(9),
        interval: 6 * 60 * 60, // 6 hours
    })
        // 8.33333% bump
        .addCurve(32 * 60 * 60, // 32 hours after launch
    new spl_token_bonding_1.ExponentialCurveConfig({
        c: 1,
        b: 0,
        pow: 1,
        frac: 2
    }), null, {
        percentage: (0, spl_utils_1.percent)(9),
        interval: 6 * 60 * 60, // 6 hours
    });
}
function run() {
    return __awaiter(this, void 0, void 0, function* () {
        console.log(process.env.ANCHOR_PROVIDER_URL);
        anchor.setProvider(anchor.Provider.env());
        const provider = anchor.getProvider();
        const tokenBondingSdk = yield spl_token_bonding_1.SplTokenBonding.init(provider);
        const tokenCollectiveSdk = yield spl_token_collective_1.SplTokenCollective.init(provider);
        const openMintKeypair = web3_js_1.Keypair.fromSecretKey(new Uint8Array(JSON.parse(fs_1.default.readFileSync(process.env.OPEN_MINT_PATH).toString())));
        const wrappedSolKeypair = web3_js_1.Keypair.fromSecretKey(new Uint8Array(JSON.parse(fs_1.default.readFileSync(process.env.WRAPPED_SOL_MINT_PATH).toString())));
        yield tokenBondingSdk.initializeSolStorage({
            mintKeypair: wrappedSolKeypair
        });
        const curve = yield tokenBondingSdk.initializeCurve({
            config: timeIncrease(new spl_token_bonding_1.TimeCurveConfig()
                .addCurve(0, new spl_token_bonding_1.ExponentialCurveConfig({
                c: 0,
                b: 0.005,
                pow: 0,
                frac: 2
            })))
        });
        const socialCurve = yield tokenBondingSdk.initializeCurve({
            config: timeIncrease(new spl_token_bonding_1.TimeCurveConfig()
                .addCurve(0, new spl_token_bonding_1.ExponentialCurveConfig({
                c: 0,
                b: 0.1,
                pow: 0,
                frac: 2
            })))
        });
        const { collective, tokenBonding } = yield tokenCollectiveSdk.createCollective({
            metadata: {
                name: "Open Collective",
                symbol: "OPEN",
                uri: "https://strata-token-metadata.s3.us-east-2.amazonaws.com/open.json"
            },
            bonding: {
                targetMintKeypair: openMintKeypair,
                curve,
                baseMint: new web3_js_1.PublicKey("So11111111111111111111111111111111111111112"),
                index: 0,
                reserveAuthority: null,
                curveAuthority: provider.wallet.publicKey,
                targetMintDecimals: 9,
                buyBaseRoyaltyPercentage: 0,
                buyTargetRoyaltyPercentage: 0,
                sellBaseRoyaltyPercentage: 0,
                sellTargetRoyaltyPercentage: 0,
                goLiveDate: new Date(1642518000 * 1000) // 9am CST on January 18th
            },
            authority: provider.wallet.publicKey,
            config: {
                isOpen: true,
                unclaimedTokenBondingSettings: {
                    curve: socialCurve,
                    buyBaseRoyalties: {
                        ownedByName: true,
                    },
                    sellBaseRoyalties: {
                        ownedByName: true,
                    },
                    buyTargetRoyalties: {
                        ownedByName: true,
                    },
                    sellTargetRoyalties: {
                        ownedByName: true,
                    },
                    minBuyBaseRoyaltyPercentage: 0,
                    maxBuyBaseRoyaltyPercentage: 0,
                    minSellBaseRoyaltyPercentage: 0,
                    maxSellBaseRoyaltyPercentage: 0,
                    minBuyTargetRoyaltyPercentage: 5,
                    maxBuyTargetRoyaltyPercentage: 5,
                    minSellTargetRoyaltyPercentage: 0,
                    maxSellTargetRoyaltyPercentage: 0,
                },
                unclaimedTokenMetadataSettings: {
                    symbol: "UNCLAIMED",
                    nameIsNameServiceName: true,
                    uri: "https://strata-token-metadata.s3.us-east-2.amazonaws.com/unclaimed.json",
                },
                claimedTokenBondingSettings: {
                    maxSellBaseRoyaltyPercentage: 10,
                    maxSellTargetRoyaltyPercentage: 10,
                }
            }
        });
        console.log(`Open Collective: ${collective}, bonding: ${tokenBonding}, open: ${openMintKeypair.publicKey}, openMetadata: ${yield (0, spl_utils_1.getMetadata)(openMintKeypair.publicKey.toBase58())}`);
    });
}
run().catch(e => {
    console.error(e);
    process.exit(1);
});
//# sourceMappingURL=bootstrap.js.map